@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser/Library General Public License version 2,
@@ -37,10 +37,10 @@ namespace Lancelot
 class LANCELOT_EXPORT ScrollBar: public Plasma::ScrollBar {
     Q_OBJECT
 
-    Q_PROPERTY ( ActivationMethod activationMethod READ activationMethod WRITE setActivationMethod )
+    Q_PROPERTY ( int activationMethod READ activationMethod WRITE setActivationMethod )
 
-    // L_WIDGET
-    // L_INCLUDE(lancelot/widgets/ScrollBar.h lancelot/lancelot.h)
+    // @puck L_WIDGET
+    // @puck L_INCLUDE(lancelot/widgets/ScrollBar.h lancelot/lancelot.h)
 
 public:
     /**
@@ -60,12 +60,12 @@ public:
      * be treated as HoverActivate
      * @param method new activation method
      */
-    void setActivationMethod(Lancelot::ActivationMethod method);
+    void setActivationMethod(int method);
 
     /**
      * @returns activation method
      */
-    Lancelot::ActivationMethod activationMethod() const;
+    int activationMethod() const;
 
 protected:
     L_Override void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
